aboutsummaryrefslogtreecommitdiff
path: root/src/auth.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/auth.rs')
-rw-r--r--src/auth.rs9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/auth.rs b/src/auth.rs
index 9cf0722..5ca59da 100644
--- a/src/auth.rs
+++ b/src/auth.rs
@@ -278,7 +278,8 @@ impl<'a, T: Device<'a>> Admin<'a, T> {
///
/// # Errors
///
/// - [`InvalidSlot`][] if the provided numlock, capslock or scrolllock slot is larger than two
///
/// # Example
///
@@ -306,9 +307,9 @@ impl<'a, T: Device<'a>> Admin<'a, T> {
let raw_config = RawConfig::try_from(config)?;
get_command_result(unsafe {
nitrokey_sys::NK_write_config(
- raw_config.numlock,
- raw_config.capslock,
- raw_config.scrollock,
+ raw_config.num_lock,
+ raw_config.caps_lock,
+ raw_config.scroll_lock,
raw_config.user_password,
false,
self.temp_password.as_ptr(),
@@ -278,7 +278,8 @@ impl<'a, T: Device<'a>> Admin<'a, T> {
/// # Errors
///
- /// - [`InvalidSlot`][] if the provided numlock, capslock or scrolllock slot is larger than two
+ /// - [`InvalidSlot`][] if the provided Num Lock, Caps Lock or Scroll Lock slot is larger than
+ /// two
///
/// # Example